/*
 * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */


#include "taskqueries.h"

using namespace Domain;

TaskQueries::TaskQueries()
{
}

TaskQueries::~TaskQueries()
{
}

